#
# spec file for package zimg
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         sover 2
Name:           zimg
Version:        3.0.5
Release:        2.2
Summary:        Scaling, colorspace conversion, and dithering library
License:        WTFPL
Group:          Development/Libraries/C and C++
URL:            https://github.com/sekrit-twc/zimg
Source0:        zimg-%{version}.tar.xz
Source99:       baselibs.conf
Patch0:         zimg-s390x-unit-tests.patch
# https://github.com/sekrit-twc/zimg/issues/214
Patch1:         zimg-gcc15.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pkgconfig

%description
The "z" image library implements the commonly required image processing
basics of scaling, colorspace conversion, and depth conversion.

%package -n libzimg%{sover}
Summary:        Scaling, colorspace conversion, and dithering library
Group:          System/Libraries

%description -n libzimg%{sover}
The "z" image library implements the commonly required image processing
basics of scaling, colorspace conversion, and depth conversion.

%package devel
Summary:        Development files for libzimg%{sover}
Group:          Development/Libraries/C and C++
Requires:       libzimg%{sover} = %{version}

%description devel
The libzimg-devel package contains libraries and header files for
developing applications that use libzimg%{sover}.

%prep
%autosetup -p1

%build
autoreconf -fiv
# do not enable tests here — they make zimg slower and the install
# rule is broken
%configure \
%ifarch armv7l
  --disable-simd \
%endif
  --disable-static
%make_build

%install
%make_install
rm -rf %{buildroot}%{_datadir}/doc/zimg
find %{buildroot} -type f -name "*.la" -delete -print

%ifnarch ppc64 ppc64le
%check
%make_build clean
%configure \
%ifarch armv7l
  --disable-simd \
%endif
  --disable-static \
  --enable-unit-test
%make_build
%make_build test/unit_test
test/unit_test
%endif

%post -n libzimg%{sover} -p /sbin/ldconfig
%postun -n libzimg%{sover} -p /sbin/ldconfig

%files -n libzimg%{sover}
%license COPYING
%doc ChangeLog README.md
%{_libdir}/libzimg.so.%{sover}*

%files devel
%doc doc/example
%{_includedir}/zimg.h
%{_includedir}/zimg++.hpp
%{_libdir}/libzimg.so
%{_libdir}/pkgconfig/zimg.pc

%changelog
* Wed Feb 12 2025 pgajdos@suse.com
- added patches
  fix https://github.com/sekrit-twc/zimg/issues/214
  + zimg-gcc15.patch
* Fri Jul 14 2023 Mia Herkt <mia@0x0.st>
- Update to 3.0.5
  * colorspace: add ST.428-1 (gamma 2.6) transfer function
  * depth: fix AVX-512 integer to float border handling (introduced in 2.6)
  * depth: fix NEON dither border handling (introduced in 3.0)
  * graph: fix clipping in alpha premultiplication (introduced in 3.0)
  * x86: optimizations for AMD Zen4 processors
- Drop e29571.patch
* Fri May  6 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 3.0.4
  * colorspace: fix ARIB STD-B67 constant-luminance EOTF
  * colorspace: filter negative values from sRGB-like transfer functions
  * common: compilation fixes on esoteric architectures
  * graph: fix active region with chroma subsampling
- Added e29571.patch from upstream to fix arm unittests
* Wed Sep 22 2021 Michael Gorse <mgorse@suse.com>
- Update to 3.0.3:
  * depth: fix out-of-bounds read in SSE2/AVX2 error diffusion
    (introduced in 2.5)
  * colorspace: revert SMPTE 240M behavior change (introduced in
    3.0.2)
  * Changes in version 3.0.2:
  * api: default to ZIMG_CPU_AUTO when graph params are null
  * colorspace: fix incorrect SMPTE 240M transfer function
  * colorspace: fix underflow in AVX-512 ST.2084 transfer functions
  * graph: fix conversion from fullrange grey to RGB
  * arm: fix data alignment
  * x86: optimizations for AMD Zen3 processors
- Add zimg-s390x-unit-tests.patch: fix unit tests on big endian
  systems.
* Thu Sep 10 2020 Dirk Mueller <dmueller@suse.com>
- update to 3.0.1:
  * graph: fix handling of default nominal_peak_luminance (introduced in 3.0)
* Wed Aug  5 2020 Mia Herkt <mia@0x0.st>
- Update to version 3.0 (API 2.4):
  * api: support alpha channel as the fourth plane
  * colorspace: accept UNSPECIFIED transfer characteristics in
    more situations
  * colorspace: fix conversion from ICtCp to ARIB STD-B67
  * depth: fix out of bounds access in SSE2 ordered dither
  * graph: rewrite for alpha channel support
  * resize: fix incorrect rounding when calculating pixel
    coordinates
  * resize: AVX-512 VNNI code paths
  * arm: NEON/ASIMD code paths
- Drop patches:
  * update-matrix3.cpp.patch
  * colorspace-fix-assertion.patch
  * colorspace-fix-assertion-part2.patch
* Wed Mar 18 2020 Martin Liška <mliska@suse.cz>
- Add colorspace-fix-assertion-part2.patch in order to address
  gh#sekrit-twc/zimg#123.
* Tue Mar 17 2020 Martin Liška <mliska@suse.cz>
- Add colorspace-fix-assertion.patch in order to fix
  build with GCC10. See gh#sekrit-twc/zimg#122.
* Mon Mar  2 2020 Martin Herkt <9+suse@cirno.systems>
- Update to version 2.9.3:
  * resize: add spline64 filter
* Thu Dec  5 2019 Martin Liška <mliska@suse.cz>
- Add update-matrix3.cpp.patch in order
  to fix boo#1158372.
* Fri Aug  2 2019 Martin Herkt <9+suse@cirno.systems>
- Switch to git checkout (GitHub tarbals lack required submodules)
- Build unit tests separately as they impact the build result and
  produce a broken install rule
- Update to version 2.9.2:
  * colorspace: fix crash on invalid conversion from unspec to
    real primaries
  * x86: additional optimizations for AMD Piledriver
  * x86: optimizations for AMD Zen2 processors
* Thu Jun 13 2019 Martin Herkt <9+suse@cirno.systems>
- Update to version 2.9.1:
  * resize: fix incorrect spline36 coefficients (introduced in 2.9)
* Fri Jun  7 2019 Martin Herkt <9+suse@cirno.systems>
- Update to version 2.9:
  * colorspace: improve accuracy of SSE2 LUT-based transfer
    functions
  * depth: AVX2 and AVX-512 code paths for limited range upsampling
  * graph: optimize tile width calculation
  * graph: reduce execution overhead
  * graph: skip processing pixels outside of active window
  * resize: change default bicubic from Mitchell-Netravali to
    Catmull-Rom
  * resize: make output bit-exact regardless of active window
    dimensions
  * x86: optimizations for AMD Piledriver and Zen1 processors
* Mon Oct 22 2018 Martin Herkt <9+suse@cirno.systems>
- Update to version 2.8:
  * api: rename colorspace enum values
  * colorspace: AVX-512 code paths for commonly used transfer
    functions
  * colorspace: optimize SSE2 LUT-based transfer functions
  * common: reduce execution overhead
  * depth: increase ordered dither pattern from 8x8 to 16x16
  * depth: use blue noise instead of white for random dither
  * depth: use different dither pattern on each color component
  * resize: optimize x86 SIMD horizontal downsampling with >8 taps
  * x86: cache detection on AMD processors
  * x86: optimizations for AMD Excavator processors
* Fri Jul 13 2018 9+suse@cirno.systems
- Update to 2.7.5:
  * depth: fix SSE2 byte->float when width+4 is mod16
  * resize: allow downsampling to very low resolutions
* Mon Apr 23 2018 dimstar@opensuse.org
- Add baselibs.conf: create libzimg2-32bit as a dependency to
  libavfilter6-32bit.
* Thu Feb  8 2018 9+suse@cirno.systems
- Update to 2.7.4
  * x86: fix crash on Yorkfield (Core 2 Quad) processors
    (introduced in 2.7)
* Wed Jan 31 2018 9+suse@cirno.systems
- Update to 2.7.3
  * resize: fix performance drop in certain resampling ratios
- Use %%license macro
- Include example code in -devel documentation
* Mon Jan 29 2018 9+suse@cirno.systems
- Update to 2.7.2
  * graph: fix image corruption in certain conversions
    (introduced in 2.7)
  * resize: fix AVX-512 horizontal resize with certain widths
    (introduced in 2.6)
* Sun Jan 14 2018 9@cirno.systems
- Update to 2.7.1
  * colorspace: fix incorrect ST.428 primaries (introduced in 2.7)
  * colorspace: preserve BTB/WTW when approximate_gamma is set
  * colorspace: optimize handling of IEC 61966-2-4 transfer
    characteristics
* Sun Dec 31 2017 9@cirno.systems
- Update to 2.7
  * colorspace: add support for additional
    matrix/transfer/primaries
  * graph: reduce buffer copies when converting from grey to color
  * graph: reduce buffer copies when performing colorspace
    conversion
  * graph: process input planes separately when possible
  * graph: optimize calculation of tile width
  * x86: automatic cache size detection for Intel processors
* Thu Nov 30 2017 9@cirno.systems
- Entry to make factory-auto happy after devel project change
  * Delete zimg-automake-1.13.patch
  * Delete zimg-5.0.0.patch
* Wed Nov 22 2017 9@cirno.systems
- Update to 2.6.3
  * resize: fix crash in AVX-512 resizer with GCC
  * resize: improve cache efficiency in AVX-512 horizontal resizers
* Mon Nov 20 2017 mpluskal@suse.com
- Clean up spec file a bit
- Drop useless service
* Fri Nov 10 2017 9@cirno.systems
- Update to 2.6.2
  * depth: fix AVX-512 clamping of negative pixels
  * graph: fix WORD greyscale to YUV conversion
* Tue Sep  5 2017 9@cirno.systems
- Update to 2.6.1
  * depth: fix SSE2 conversions with mod4 and mod8 widths
    (introduced in 2.6)
  * resize: fix heap corruption in AVX2 horizontal resizer
    (introduced in 2.6)
* Fri Aug 18 2017 9@cirno.systems
- Rename to zimg to match upstream name (see OBS request #516938)
- Update to 2.6a
  * api: add missing version requirements to comments
  * example: add ZIMG_CPU_AUTO_64B to API example
  * example: add more comments
  * colorspace: fix unit tests on 32-bit x86
* Mon Aug 14 2017 9@cirno.systems
- Update to version 2.6
  * api: add ZIMG_CPU_AUTO_64B for AVX-512 compatibility
  * colorspace: add support for ITU-R BT.2100 ICtCp
  * colorspace: add support for constant luminance ITU-R BT.2100 HLG
  * colorspace: add support for SMPTE ST.431-2 (traditional DCI-P3)
  * colorspace: add support for chromaticity-derived NCL/CL matrices
  * colorspace: assume 1000 cd/m^2 peak luminance for HLG
  * colorspace: fix crash on bad colorspace definition
  * depth: optimized SSE2/AVX2 conversions with 8/16-bit input
  * resize: optimized AVX2 horizontal upsampler memory usage
  * resize: optimized x86 SIMD function calling
  * x86: AVX-512 code paths for key functions
* Sun Jul  9 2017 jengelh@inai.de
- Fix RPM groups
- Edit description to avoid potential confusion with the
  z/zip compression library (zlib).
- Replace ancient -j%%jobs by %%_smp_mflags.
* Thu Jul  6 2017 9@cirno.systems
- Copy to OBS, add (disabled) download _service
* Thu Jun 22 2017 joerg.lorenzen@ki.tng.de
- Update to version 2.5.1
  + depth: fix AVX2 conversion from half to byte/word
    (introduced in 2.1).
* Thu Mar 30 2017 joerg.lorenzen@ki.tng.de
- Initial package, version 2.5
